==> zio-aws-appflow_2.13-5.17.205.1-sources.jar: zio/aws/appflow/model/SAPODataDestinationProperties.scala <==
package zio.aws.appflow.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import zio.aws.appflow.model.primitives.{Name, Object}
import scala.jdk.CollectionConverters._
final case class SAPODataDestinationProperties(
    objectPath: Object,
    successResponseHandlingConfig: Optional[
      zio.aws.appflow.model.SuccessResponseHandlingConfig
    ] = Optional.Absent,
    idFieldNames: Optional[Iterable[Name]] = Optional.Absent,
    errorHandlingConfig: Optional[zio.aws.appflow.model.ErrorHandlingConfig] =
      Optional.Absent,
    writeOperationType: Optional[zio.aws.appflow.model.WriteOperationType] =
      Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.appflow.model.SAPODataDestinationProperties = {
    import SAPODataDestinationProperties.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.appflow.model.SAPODataDestinationProperties
      .builder()
      .objectPath(Object.unwrap(objectPath): java.lang.String)
      .optionallyWith(
        successResponseHandlingConfig.map(value => value.buildAwsValue())
      )(_.successResponseHandlingConfig)
      .optionallyWith(
        idFieldNames.map(value =>
          value.map { item =>
            Name.unwrap(item): java.lang.String
          }.asJavaCollection
        )
      )(_.idFieldNames)
      .optionallyWith(errorHandlingConfig.map(value => value.buildAwsValue()))(
        _.errorHandlingConfig
      )
      .optionallyWith(writeOperationType.map(value => value.unwrap))(
        _.writeOperationType
      )
      .build()
  }
  def asReadOnly: zio.aws.appflow.model.SAPODataDestinationProperties.ReadOnly =
    zio.aws.appflow.model.SAPODataDestinationProperties.wrap(buildAwsValue())
}
object SAPODataDestinationProperties {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.appflow.model.SAPODataDestinationProperties
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.appflow.model.SAPODataDestinationProperties =
      zio.aws.appflow.model.SAPODataDestinationProperties(
        objectPath,
        successResponseHandlingConfig.map(value => value.asEditable),
        idFieldNames.map(value => value),
        errorHandlingConfig.map(value => value.asEditable),
        writeOperationType.map(value => value)
      )
    def objectPath: Object
    def successResponseHandlingConfig
        : Optional[zio.aws.appflow.model.SuccessResponseHandlingConfig.ReadOnly]
    def idFieldNames: Optional[List[Name]]
    def errorHandlingConfig
        : Optional[zio.aws.appflow.model.ErrorHandlingConfig.ReadOnly]
    def writeOperationType: Optional[zio.aws.appflow.model.WriteOperationType]
    def getObjectPath: ZIO[Any, Nothing, Object] = ZIO.succeed(objectPath)
    def getSuccessResponseHandlingConfig: ZIO[
      Any,
      AwsError,
      zio.aws.appflow.model.SuccessResponseHandlingConfig.ReadOnly
    ] = AwsError.unwrapOptionField(
      "successResponseHandlingConfig",
      successResponseHandlingConfig
    )
    def getIdFieldNames: ZIO[Any, AwsError, List[Name]] =
      AwsError.unwrapOptionField("idFieldNames", idFieldNames)
    def getErrorHandlingConfig: ZIO[
      Any,
      AwsError,
      zio.aws.appflow.model.ErrorHandlingConfig.ReadOnly
    ] = AwsError.unwrapOptionField("errorHandlingConfig", errorHandlingConfig)
    def getWriteOperationType
        : ZIO[Any, AwsError, zio.aws.appflow.model.WriteOperationType] =
      AwsError.unwrapOptionField("writeOperationType", writeOperationType)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.appflow.model.SAPODataDestinationProperties
  ) extends zio.aws.appflow.model.SAPODataDestinationProperties.ReadOnly {
    override val objectPath: Object =
      zio.aws.appflow.model.primitives.Object(impl.objectPath())
    override val successResponseHandlingConfig: Optional[
      zio.aws.appflow.model.SuccessResponseHandlingConfig.ReadOnly
    ] = zio.aws.core.internal
      .optionalFromNullable(impl.successResponseHandlingConfig())
      .map(value =>
        zio.aws.appflow.model.SuccessResponseHandlingConfig.wrap(value)
      )
    override val idFieldNames: Optional[List[Name]] = zio.aws.core.internal
      .optionalFromNullable(impl.idFieldNames())
      .map(value =>
        value.asScala.map { item =>
          zio.aws.appflow.model.primitives.Name(item)
        }.toList
      )
    override val errorHandlingConfig
        : Optional[zio.aws.appflow.model.ErrorHandlingConfig.ReadOnly] =
      zio.aws.core.internal
        .optionalFromNullable(impl.errorHandlingConfig())
        .map(value => zio.aws.appflow.model.ErrorHandlingConfig.wrap(value))
    override val writeOperationType
        : Optional[zio.aws.appflow.model.WriteOperationType] =
      zio.aws.core.internal
        .optionalFromNullable(impl.writeOperationType())
        .map(value => zio.aws.appflow.model.WriteOperationType.wrap(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.appflow.model.SAPODataDestinationProperties
  ): zio.aws.appflow.model.SAPODataDestinationProperties.ReadOnly = new Wrapper(
    impl
  )
}

==> zio-aws-appflow_3-5.17.203.2-sources.jar: zio/aws/appflow/model/SAPODataDestinationProperties.scala <==
package zio.aws.appflow.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import zio.aws.appflow.model.primitives.{Name, Object}
import scala.jdk.CollectionConverters.*
final case class SAPODataDestinationProperties(
    objectPath: Object,
    successResponseHandlingConfig: Optional[
      zio.aws.appflow.model.SuccessResponseHandlingConfig
    ] = Optional.Absent,
    idFieldNames: Optional[Iterable[Name]] = Optional.Absent,
    errorHandlingConfig: Optional[zio.aws.appflow.model.ErrorHandlingConfig] =
      Optional.Absent,
    writeOperationType: Optional[zio.aws.appflow.model.WriteOperationType] =
      Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.appflow.model.SAPODataDestinationProperties = {
    import SAPODataDestinationProperties.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.appflow.model.SAPODataDestinationProperties
      .builder()
      .objectPath(Object.unwrap(objectPath): java.lang.String)
      .optionallyWith(
        successResponseHandlingConfig.map(value => value.buildAwsValue())
      )(_.successResponseHandlingConfig)
      .optionallyWith(
        idFieldNames.map(value =>
          value.map { item =>
            Name.unwrap(item): java.lang.String
          }.asJavaCollection
        )
      )(_.idFieldNames)
      .optionallyWith(errorHandlingConfig.map(value => value.buildAwsValue()))(
        _.errorHandlingConfig
      )
      .optionallyWith(writeOperationType.map(value => value.unwrap))(
        _.writeOperationType
      )
      .build()
  }
  def asReadOnly: zio.aws.appflow.model.SAPODataDestinationProperties.ReadOnly =
    zio.aws.appflow.model.SAPODataDestinationProperties.wrap(buildAwsValue())
}
object SAPODataDestinationProperties {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.appflow.model.SAPODataDestinationProperties
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.appflow.model.SAPODataDestinationProperties =
      zio.aws.appflow.model.SAPODataDestinationProperties(
        objectPath,
        successResponseHandlingConfig.map(value => value.asEditable),
        idFieldNames.map(value => value),
        errorHandlingConfig.map(value => value.asEditable),
        writeOperationType.map(value => value)
      )
    def objectPath: Object
    def successResponseHandlingConfig
        : Optional[zio.aws.appflow.model.SuccessResponseHandlingConfig.ReadOnly]
    def idFieldNames: Optional[List[Name]]
    def errorHandlingConfig
        : Optional[zio.aws.appflow.model.ErrorHandlingConfig.ReadOnly]
    def writeOperationType: Optional[zio.aws.appflow.model.WriteOperationType]
    def getObjectPath: ZIO[Any, Nothing, Object] = ZIO.succeed(objectPath)
    def getSuccessResponseHandlingConfig: ZIO[
      Any,
      AwsError,
      zio.aws.appflow.model.SuccessResponseHandlingConfig.ReadOnly
    ] = AwsError.unwrapOptionField(
      "successResponseHandlingConfig",
      successResponseHandlingConfig
    )
    def getIdFieldNames: ZIO[Any, AwsError, List[Name]] =
      AwsError.unwrapOptionField("idFieldNames", idFieldNames)
    def getErrorHandlingConfig: ZIO[
      Any,
      AwsError,
      zio.aws.appflow.model.ErrorHandlingConfig.ReadOnly
    ] = AwsError.unwrapOptionField("errorHandlingConfig", errorHandlingConfig)
    def getWriteOperationType
        : ZIO[Any, AwsError, zio.aws.appflow.model.WriteOperationType] =
      AwsError.unwrapOptionField("writeOperationType", writeOperationType)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.appflow.model.SAPODataDestinationProperties
  ) extends zio.aws.appflow.model.SAPODataDestinationProperties.ReadOnly {
    override val objectPath: Object =
      zio.aws.appflow.model.primitives.Object(impl.objectPath())
    override val successResponseHandlingConfig: Optional[
      zio.aws.appflow.model.SuccessResponseHandlingConfig.ReadOnly
    ] = zio.aws.core.internal
      .optionalFromNullable(impl.successResponseHandlingConfig())
      .map(value =>
        zio.aws.appflow.model.SuccessResponseHandlingConfig.wrap(value)
      )
    override val idFieldNames: Optional[List[Name]] = zio.aws.core.internal
      .optionalFromNullable(impl.idFieldNames())
      .map(value =>
        value.asScala.map { item =>
          zio.aws.appflow.model.primitives.Name(item)
        }.toList
      )
    override val errorHandlingConfig
        : Optional[zio.aws.appflow.model.ErrorHandlingConfig.ReadOnly] =
      zio.aws.core.internal
        .optionalFromNullable(impl.errorHandlingConfig())
        .map(value => zio.aws.appflow.model.ErrorHandlingConfig.wrap(value))
    override val writeOperationType
        : Optional[zio.aws.appflow.model.WriteOperationType] =
      zio.aws.core.internal
        .optionalFromNullable(impl.writeOperationType())
        .map(value => zio.aws.appflow.model.WriteOperationType.wrap(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.appflow.model.SAPODataDestinationProperties
  ): zio.aws.appflow.model.SAPODataDestinationProperties.ReadOnly = new Wrapper(
    impl
  )
}
